@@ -8,7 +8,7 @@ pcropt1 <- function (object, fact = 3, opt = FALSE, ...)
     eff <- NULL
     init.exp <- NULL
     init.sig <- NULL
-    compl <- try(efficiency(object, plot = FALSE, ...))
+    compl <- try(efficiency(object, plot = FALSE))
     if (inherits(compl, "try-error")) 
         stop("Could not initialize optimization. Try different 'fact'!")
     cpD1 <- round(compl$cpD1)
@@ -24,8 +24,8 @@ pcropt1 <- function (object, fact = 3, opt = FALSE, ...)
             newCurve <- update(object, data = newData)
  		  F0 <- pcrpred(newCurve, which = "y", newdata = 0)
             if (opt) 
-                newCurve <- mchoice(newCurve)
-            compl <- try(efficiency(newCurve, ...))
+                newCurve <- mchoice(newCurve, ...)
+            compl <- try(efficiency(newCurve))
             window.l <- c(window.l, i - lower)
             window.u <- c(window.u, j - upper)
             aicc <- c(aicc, compl$AICc)
